@@ -1,9 +1,9 @@
+from django.contrib.auth import get_user_model
 from django.contrib.auth.models import Group
-from django.shortcuts import render_to_response, get_object_or_404
+from django.shortcuts import render, get_object_or_404
 from django.views.generic import ListView
 from django.template import RequestContext
 from guardian.decorators import permission_required_or_403
-from guardian.compat import get_user_model
 
 from .models import Post
 
@@ -24,6 +24,6 @@ def post_detail(request, slug, **kwargs):
         'users': User.objects.all(),
         'groups': Group.objects.all(),
     }
-    return render_to_response(
-        'posts/post_detail.html', data,
+    return render(
+        request, 'posts/post_detail.html', data,
         RequestContext(request))
