@@ -1,13 +1,12 @@
 """
 Implementation of per object permissions for Django.
 """
-from __future__ import unicode_literals
 from . import checks
 
 default_app_config = 'guardian.apps.GuardianConfig'
 
 # PEP 396: The __version__ attribute's value SHOULD be a string.
-__version__ = '1.4.9'
+__version__ = '2.0.0'
 
 # Compatibility to eg. django-rest-framework
 VERSION = tuple(int(x) for x in __version__.split('.')[:3])
@@ -18,7 +17,7 @@ def get_version():
 
 
 def monkey_patch_user():
-    from .compat import get_user_model
+    from django.contrib.auth import get_user_model
     from .utils import get_anonymous_user
     from .models import UserObjectPermission
     User = get_user_model()
