@@ -1,4 +1,3 @@
-from __future__ import unicode_literals
 from django import forms
 from django.utils.translation import ugettext as _
 from guardian.shortcuts import assign_perm, get_group_perms, get_perms_for_model, get_user_perms, remove_perm
@@ -18,7 +17,7 @@ class BaseObjectPermissionsForm(forms.Form):
           permissions"
         """
         self.obj = obj
-        super(BaseObjectPermissionsForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         field_name = self.get_obj_perms_field_name()
         self.fields[field_name] = self.get_obj_perms_field()
 
@@ -119,7 +118,7 @@ class UserObjectPermissionsForm(BaseObjectPermissionsForm):
 
     def __init__(self, user, *args, **kwargs):
         self.user = user
-        super(UserObjectPermissionsForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def get_obj_perms_field_initial(self):
         perms = get_user_perms(self.user, self.obj)
@@ -132,14 +131,15 @@ class UserObjectPermissionsForm(BaseObjectPermissionsForm):
 
         Should be called *after* form is validated.
         """
-        perms = self.cleaned_data[self.get_obj_perms_field_name()]
-        model_perms = [c[0] for c in self.get_obj_perms_field_choices()]
+        perms = set(self.cleaned_data[self.get_obj_perms_field_name()])
+        model_perms = set([c[0] for c in self.get_obj_perms_field_choices()])
+        init_perms = set(self.get_obj_perms_field_initial())
 
-        to_remove = set(model_perms) - set(perms)
+        to_remove = (model_perms - perms) & init_perms
         for perm in to_remove:
             remove_perm(perm, self.user, self.obj)
 
-        for perm in perms:
+        for perm in perms - init_perms:
             assign_perm(perm, self.user, self.obj)
 
 
@@ -166,7 +166,7 @@ class GroupObjectPermissionsForm(BaseObjectPermissionsForm):
 
     def __init__(self, group, *args, **kwargs):
         self.group = group
-        super(GroupObjectPermissionsForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def get_obj_perms_field_initial(self):
         perms = get_group_perms(self.group, self.obj)
@@ -179,12 +179,13 @@ class GroupObjectPermissionsForm(BaseObjectPermissionsForm):
 
         Should be called *after* form is validated.
         """
-        perms = self.cleaned_data[self.get_obj_perms_field_name()]
-        model_perms = [c[0] for c in self.get_obj_perms_field_choices()]
+        perms = set(self.cleaned_data[self.get_obj_perms_field_name()])
+        model_perms = set([c[0] for c in self.get_obj_perms_field_choices()])
+        init_perms = set(self.get_obj_perms_field_initial())
 
-        to_remove = set(model_perms) - set(perms)
+        to_remove = (model_perms - perms) & init_perms
         for perm in to_remove:
             remove_perm(perm, self.group, self.obj)
 
-        for perm in perms:
+        for perm in perms - init_perms:
             assign_perm(perm, self.group, self.obj)
